//
//  HorizontalGrideView.m
//  HorizontalGrideView
//
//  Created by Vivitickey on 2017/5/17.
//  Copyright © 2017年 test. All rights reserved.
//

#import "HorizontalGrideView.h"
#import "HorizontalGrideCollectionViewLayout.h"
#import <Masonry/Masonry.h>
#import <SDWebImage/UIImageView+WebCache.h>
@interface HorizontalGrideViewCell : UICollectionViewCell

@property (strong, nonatomic)   UILabel         *titleLabel;

@property (strong, nonatomic)   UIImageView     *iconImageView;

@end

@implementation HorizontalGrideViewCell

- (instancetype)initWithFrame:(CGRect)frame
{
    self = [super initWithFrame:frame];
    if (self) {
        _titleLabel = [UILabel new];
        _titleLabel.textAlignment = NSTextAlignmentCenter;
        _titleLabel.font = [UIFont systemFontOfSize:13];
        [self.contentView addSubview:_titleLabel];
        _iconImageView = [UIImageView new];
        [self.contentView addSubview:_iconImageView];
        
        CGFloat width = 40;
        self.iconImageView.layer.cornerRadius = width / 2;
        self.iconImageView.clipsToBounds = YES;
        
        [_titleLabel mas_makeConstraints:^(MASConstraintMaker *make) {
            make.left.right.bottom.equalTo(self.contentView);
            make.height.mas_equalTo(30);
        }];
        
        [_iconImageView mas_makeConstraints:^(MASConstraintMaker *make) {
            make.size.mas_equalTo(CGSizeMake(width, width));
            make.centerX.equalTo(self.contentView);
            make.bottom.equalTo(_titleLabel.mas_top);
        }];
    }
    return self;
}

@end
@interface HorizontalGrideView ()<UICollectionViewDelegate,UICollectionViewDataSource,UIScrollViewDelegate>

@property (strong,nonatomic) UICollectionView                       *collectionView;

@property (strong,nonatomic) UIPageControl                          *pageControl;

@property (strong,nonatomic) HorizontalGrideCollectionViewLayout  *layout;

@end

@implementation HorizontalGrideView

- (UIPageControl *)pageControl {
    if(_pageControl == nil) {
        _pageControl = [UIPageControl new];
        _pageControl.pageIndicatorTintColor = [UIColor lightGrayColor];
        if(self.delegate && [self.delegate respondsToSelector:@selector(colorForCurrentPageControlInHorizontalGrideView:)]) {
            _pageControl.currentPageIndicatorTintColor = [self.delegate colorForCurrentPageControlInHorizontalGrideView:self];
        } else {
            _pageControl.currentPageIndicatorTintColor = [UIColor grayColor];
        }
        [self addSubview:_pageControl];
        [_pageControl mas_makeConstraints:^(MASConstraintMaker *make) {
            make.left.bottom.right.equalTo(self);
            make.height.mas_equalTo(20);
        }];
    }
    return _pageControl;
}

-(UICollectionView *)collectionView{
    
    if (_collectionView == nil) {
        self.layout = [HorizontalGrideCollectionViewLayout new];
        
        //设置行数
        if (self.delegate && [self.delegate respondsToSelector:@selector(numberOfRowsPerPageInHorizontalGrideView:)]) {
            self.layout.rowCount = [self.delegate numberOfRowsPerPageInHorizontalGrideView:self];
        }else{
            self.layout.rowCount = 2;
        }
        
        // 设置列数
        if(self.delegate && [self.delegate respondsToSelector:@selector(numberOfColumnsPerPageInHorizontalGrideView:)]) {
            self.layout.columCount = [self.delegate numberOfColumnsPerPageInHorizontalGrideView:self];
        } else {
            self.layout.columCount = 4;
        }
        _collectionView = [[UICollectionView alloc] initWithFrame:CGRectZero collectionViewLayout:self.layout];
        _collectionView.pagingEnabled = YES;
        _collectionView.showsVerticalScrollIndicator = NO;
        _collectionView.showsHorizontalScrollIndicator = NO;
        _collectionView.backgroundColor = [UIColor clearColor];
        [_collectionView registerClass:[HorizontalGrideViewCell class] forCellWithReuseIdentifier:@"CELL"];
        
        _collectionView.delegate = self;
        _collectionView.dataSource = self;
        [self addSubview:_collectionView];
        [_collectionView mas_makeConstraints:^(MASConstraintMaker *make) {
            make.left.top.right.equalTo(self);
            make.bottom.equalTo(self.pageControl.mas_top);
        }];
    }
    return _collectionView;
}

/**
 刷新
 */
-(void)reloadData{
    [self.collectionView reloadData];
    
    self.pageControl.numberOfPages = [self.layout pageCount];
    
    self.pageControl.currentPage = 0;
    
}

#pragma mark - UIScrollViewDelegate -
- (void)scrollViewDidEndDecelerating:(UIScrollView *)scrollView {
    self.pageControl.currentPage = scrollView.contentOffset.x / scrollView.frame.size.width;
}


#pragma mark - UICollectionViewDataSource -
- (NSInteger)numberOfSectionsInCollectionView:(UICollectionView *)collectionView {
    return 1;
}

- (NSInteger)collectionView:(UICollectionView *)collectionView numberOfItemsInSection:(NSInteger)section {
    NSInteger count = 0;
    if(self.dataSource && [self.dataSource respondsToSelector:@selector(numberOfItemsInHorizontalGrideView:)]) {
        count = [self.dataSource numberOfItemsInHorizontalGrideView:self];
    }
    return count;
}

- (HorizontalGrideViewCell *)collectionView:(UICollectionView *)collectionView cellForItemAtIndexPath:(NSIndexPath *)indexPath {
    HorizontalGrideViewCell *cell = [collectionView dequeueReusableCellWithReuseIdentifier:@"CELL" forIndexPath:indexPath];
    NSString *title = @"";
    if(self.dataSource && [self.dataSource respondsToSelector:@selector(horizontalGrideView:titleForItemAtIndex:)]) {
        title = [self.dataSource horizontalGrideView:self titleForItemAtIndex:indexPath.row];
    }
    cell.titleLabel.text = title;
    
    if(self.dataSource && [self.dataSource respondsToSelector:@selector(horizontalGrideView:iconURLForItemAtIndex:)]) {
        NSURL *url = [self.dataSource horizontalGrideView:self iconURLForItemAtIndex:indexPath.row];
        if(self.defaultImage) {
            [cell.iconImageView sd_setImageWithURL:url placeholderImage:self.defaultImage];
        } else {
            [cell.iconImageView sd_setImageWithURL:url];
        }
    }
    
    
    return cell;
}


#pragma mark - UICollectionViewDelegate -
- (void)collectionView:(UICollectionView *)collectionView didSelectItemAtIndexPath:(NSIndexPath *)indexPath {
    if(self.delegate && [self.delegate respondsToSelector:@selector(horizontalGrideView:didSelectItemAtIndex:)]) {
        [self.delegate horizontalGrideView:self didSelectItemAtIndex:indexPath.row];
    }
}
@end
